Examples
========

This section contains worked examples using aerosoltools on real or simulated data.

.. toctree::
   :maxdepth: 1

   examples/Quick load and plot data
   examples/Load multiple files and time adjustments
   examples/Defining time segments, getting statistics, and plotting PSD
